#ifndef STATICTIP_H
#define STATICTIP_H

#include <gtk/gtk.h>


/*
 *	Widget Name:
 */
#define STATIC_TIP_WIDGET_NAME	"gtk-tooltips"


/*
 *	Aligns:
 */
typedef enum {
	STATIC_TIP_ALIGN_POINTER_MIN,	/* Left/top of pointer */
	STATIC_TIP_ALIGN_POINTER_CENTER,/* Center of pointer */
	STATIC_TIP_ALIGN_POINTER_MAX,	/* Right/bottom of pointer */
	STATIC_TIP_ALIGN_WIDGET_MIN,	/* Left/top of widget */
	STATIC_TIP_ALIGN_WIDGET_CENTER,	/* Center of widget */
	STATIC_TIP_ALIGN_WIDGET_MAX,	/* Right/bottom of widget */
	STATIC_TIP_ALIGN_WIDGET_VALUE,	/* Relative to widget's upper left corner */
	STATIC_TIP_ALIGN_ROOT_VALUE,	/* Relative to desktop's upper left corner */ 
} StaticTipAlign;


extern void StaticTipSet(
	GtkWidget *w, const gchar *text,
	StaticTipAlign x_align, StaticTipAlign y_align,
	gint x, gint y
);


#endif	/* STATICTIP_H */
